sqlobject.tests.test_boundattributes module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_boundattributes module

class `sqlobject.tests.test_boundattributes.` `AttrReplace`(*args, **kw)

  Bases: `sqlobject.boundattributes.BoundAttribute`

  `declarative_count` = 5
  `make_object` = <bound class method AttrReplace.make_object>
  `replace` = None

class `sqlobject.tests.test_boundattributes.` `Holder`(name)

  Bases: `object`

class `sqlobject.tests.test_boundattributes.` `SOTestMe`

  Bases: `object`

`sqlobject.tests.test_boundattributes.` `test_1`()